﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Net;
using System.IO;
using System.Collections.Specialized;

namespace EricWillis.Pop2Ticket.Unfuddle
{
    // http://unfuddle.com/docs/api/data_models#ticket

    /// <summary>
    /// An Unfuddle ticket
    /// </summary>
    public class Ticket
    {
        #region Privates
        
        private TicketPriority _priority;
        private String _summary;
        private String _description;

        #endregion

        #region Properties
        
        /// <summary>
        /// Priority of ticket
        /// </summary>
        public TicketPriority Priority
        {
            get { return this._priority; }
        }

        /// <summary>
        /// Summary of ticket (subject)
        /// </summary>
        public String Summary
        {
            get { return this._summary; }
        }

        /// <summary>
        /// Description of ticket (in-depth)
        /// </summary>
        public String Description
        {
            get { return this._description; }
        }

        #endregion

        #region Constructors
        
        /// <summary>
        /// Create a new ticket with a default priority of normal
        /// </summary>
        public Ticket()
            : this(TicketPriority.Normal, String.Empty, String.Empty)
        { }

        /// <summary>
        /// Create a new ticket
        /// </summary>
        /// <param name="priority">Priority of ticket</param>
        /// <param name="summary">Summary of ticket (subject)</param>
        /// <param name="description">Description of ticket (in-depth)</param>
        internal Ticket(TicketPriority priority, String summary, String description)
        {
            this._priority = priority;
            this._summary = summary;
            this._description = description;
        }

        #endregion
    }
}
